@@ -1,11 +1,43 @@
-/*
-==============================================================================
-        chadic.h
-                1990/12/06/Thu  Yutaka MYOKI(Nagao Lab., KUEE)
-                1990/01/09/Wed  Last Modified
-                                          >>> 94/02 changed by T.Nakamura <<<
-==============================================================================
-*/
+/*-
+ * chadic.h
+ *
+ * Copyright (c) 2000 Nara Institute of Science and Technology
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *      This product includes software developed by Nara Institute of 
+ *      Science and Technology.
+ * 4. The name Nara Institute of Science and Technology may not be used to
+ *    endorse or promote products derived from this software without specific
+ *    prior written permission.
+ *    
+ *
+ * THIS SOFTWARE IS PROVIDED BY Nara Institute of Science and Technology 
+ * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A 
+ * PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE Nara Institute
+ * of Science and Technology BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+ * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * 1990/12/06/Thu  Yutaka MYOKI(Nagao Lab., KUEE)
+ * 1994/02 changed by T.Nakamura 
+ *
+ * $Id: chadic.h,v 1.10.4.1 2000/12/18 20:08:30 masayu-a Exp $
+ */
 #ifndef __CHADIC_H__
 #define __CHADIC_H__
 
